import { Request, Response } from "express";
import MemberService from "../../service/memberService";
import MemberFactory from "../../factory/admin/member";

/**
 * @description get all members
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getAllMembers(req: Request, res: Response): Promise<any> {
  let members = await MemberService.getAll();

  res.json(MemberFactory.mapToBase(members));
}

/**
 * @description get member by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getMemberById(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.id);
  let member = await MemberService.getById(memberId);

  res.json(MemberFactory.mapToSingle(member));
}

/**
 * @description get memberships by member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getMembershipsByMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.json([]);
}

/**
 * @description get awards by member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getAwardsByMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.json([]);
}

/**
 * @description get qualifications by member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getQualificationsByMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.json([]);
}

/**
 * @description get executive positions by member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getExecutivePositionsByMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.json([]);
}

/**
 * @description get communications by member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function getCommunicationsByMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.json([]);
}

/**
 * @description create member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function createMember(req: Request, res: Response): Promise<any> {
  res.status(200).send(0);
}

/**
 * @description add memberships to member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function addMembershipToMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.sendStatus(204);
}

/**
 * @description add awards to member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function addAwardToMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.sendStatus(204);
}

/**
 * @description add qualifications to member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function addQualificationToMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.sendStatus(204);
}

/**
 * @description add executive positions to member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function addExecutivePositionToMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.sendStatus(204);
}

/**
 * @description add communications to member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function addCommunicationToMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);

  res.sendStatus(204);
}

/**
 * @description update member by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateMemberById(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.id);

  res.sendStatus(204);
}

/**
 * @description update membership of member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateMembershipOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description update award of member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateAwardOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description update qualification of member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateQualificationOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description update executive position of member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateExecutivePositionOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description update communication of member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function updateCommunicationOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description delete member by id
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteMemberById(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.id);

  res.sendStatus(204);
}

/**
 * @description delete membership from member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteMembershipOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description delete award from member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteAwardOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description delete qualification from member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteQualificationOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description delete executive position from member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteExecutivePositionOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}

/**
 * @description delete communication from member
 * @param req {Request} Express req object
 * @param res {Response} Express res object
 * @returns {Promise<*>}
 */
export async function deleteCommunicationOfMember(req: Request, res: Response): Promise<any> {
  const memberId = parseInt(req.params.memberId);
  const recordId = parseInt(req.params.recordId);

  res.sendStatus(204);
}
